<?php

// Exit if accessed directly
if ( !defined ( 'ABSPATH' ) ) {
    exit;
}

// Don't duplicate me!
if ( !class_exists ( 'ReduxFramework_extension_accordion' ) ) {

    /**
     * Main ReduxFramework_extension_accordion extension class
     *
     * @since       1.0.0
     */
    class ReduxFramework_extension_accordion {

        public static $version = '1.0.1';
        
        public $ext_name = 'Accordion';
        public $min_redux_version = '';
        
        // Protected vars
        protected $parent;
        public static $theInstance;
        public static $ext_url;
        public $field_id = '';

        /**
         * Class Constructor. Defines the args for the extions class
         *
         * @since       1.0.0
         * @access      public
         *
         * @param       array $parent Parent settings.
         *
         * @return      void
         */
        public function __construct ( $parent ) {

            $redux_ver = ReduxFramework::$_version;

            // Set parent object
            $this->parent = $parent;

            if (is_admin() && !$this->is_minimum_version()) {
                return;
            }
            
            // Set field name
            $this->field_name = 'accordion';

            // Set instance
            self::$theInstance = $this;

            // Uncomment when customizer works - kp
            //include_once($this->extension_dir . 'multi-media/inc/class.customizer.php');
            //new ReduxColorSchemeCustomizer($parent, $this->extension_dir);
            // Adds the local field
            add_filter ( 'redux/' . $this->parent->args[ 'opt_name' ] . '/field/class/' . $this->field_name, array(
                &$this,
                'overload_field_path'
            ) );
        }

        static public function getInstance () {
            return self::$theInstance;
        }

        static public function getExtURL () {
            return self::$ext_url;
        }

        // Forces the use of the embeded field path vs what the core typically would use
        public function overload_field_path ( $field ) {
            return dirname ( __FILE__ ) . '/' . $this->field_name . '/field_' . $this->field_name . '.php';
        }
        
        private function is_minimum_version () {
            $redux_ver = ReduxFramework::$_version;

            if ($this->min_redux_version != '') {
                if (version_compare($redux_ver, $this->min_redux_version) < 0) {
                    $msg = '<strong>' . esc_html__( 'The', 'allcom') . ' ' .  $this->ext_name . ' ' .  esc_html__('extension requires', 'allcom') . ' Redux Framework ' . esc_html__('version', 'allcom') . ' ' . $this->min_redux_version . ' ' .  esc_html__('or higher.','allcom' ) . '</strong>&nbsp;&nbsp;' . esc_html__( 'You are currently running', 'allcom') . ' Redux Framework ' . esc_html__('version','allcom' ) . ' ' . $redux_ver . '.<br/><br/>' . esc_html__('This field will not render in your option panel, and featuress of this extension will not be available until the latest version of','allcom' ) . ' Redux Framework ' . esc_html__('has been installed.','allcom' );
                    
                    $data = array(
                        'parent'    => $this->parent,
                        'type'      => 'error',
                        'msg'       => $msg,
                        'id'        => $this->ext_name . '_notice_' . self::$version,
                        'dismiss'   => false
                    );
                    
                    if (method_exists('Redux_Admin_Notices', 'set_notice')) {
                        Redux_Admin_Notices::set_notice($data);
                    } else {
                        echo '<div class="error">';
                        echo     '<p>';
                        echo         $msg;
                        echo     '</p>';
                        echo '</div>';
                    }

                    return false;
                }
            }
            
            return true;
        }        
    }
}