<?php

// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

// Don't duplicate me!
if( !class_exists( 'ReduxFramework_extension_css_layout' ) ) {
    
    
    /**
    * Main ReduxFramework css_layout extension class
    *
    * @since       1.0.0
    */
    class ReduxFramework_extension_css_layout {
        public static $version = '1.0.3';
        
        public $ext_name = 'CSS Layout';
        public $min_redux_version = '';
        
        // Protected vars
        protected $parent;
        public $extension_url;
        public $extension_dir;
        public static $theInstance;
        public $field_id = '';
        private $class_css = '';
        
        /**
        * Class Constructor. Defines the args for the extions class
        *
        * @since       1.0.0
        * @access      public
        * @param       array $parent Parent settings.
        * @return      void
        */
        public function __construct( $parent ) {
            $redux_ver = ReduxFramework::$_version;
            
            // Set parent object
            $this->parent = $parent;
            
            if (is_admin() && !$this->is_minimum_version()) {
                return;
            }
            
            // Set extension dir
            if ( empty( $this->extension_dir ) ) {
                $this->extension_dir = trailingslashit( str_replace( '\\', '/', dirname( __FILE__ ) ) );
            }
            
            // Set field name
            $this->field_name = 'css_layout';
            
            // Set instance
            self::$theInstance = $this;
            
            include_once($this->extension_dir . 'css_layout/inc/class.css_layout_functions.php');
            
            // Adds the local field
            add_filter( 'redux/'.$this->parent->args['opt_name'].'/field/class/'. $this->field_name, array( &$this, 'overload_field_path' ) );
            
            // Register hook - to get field id and prep helper
            add_action('redux/options/' . $this->parent->args['opt_name'] . '/field/' . $this->field_name . '/register', array($this, 'register_field'));
            
        }
        
        public function register_field($data) {
            $this->field_id = $data['id'];
            ReduxCssLayoutFunctions::$_field_id = $data['id'];
            
            $output_short = isset($data['output-shorthand']) ? $data['output-shorthand'] : false;
            ReduxCssLayoutFunctions::$output_shorthand = $output_short;
        }
        
        static public function getInstance() {
            return self::$theInstance;
        }
        
        // Forces the use of the embeded field path vs what the core typically would use
        public function overload_field_path($field) {
            return dirname(__FILE__).'/'.$this->field_name.'/field_'.$this->field_name.'.php';
        }
        
        private function is_minimum_version () {
            $redux_ver = ReduxFramework::$_version;
            
            if ($this->min_redux_version != '') {
                if (version_compare($redux_ver, $this->min_redux_version) < 0) {
                    $msg = '<strong>' . esc_html__( 'The', 'allcom') . ' ' .  $this->ext_name . ' ' .  esc_html__('extension requires', 'allcom') . ' Redux Framework ' . esc_html__('version', 'allcom') . ' ' . $this->min_redux_version . ' ' .  esc_html__('or higher.','allcom' ) . '</strong>&nbsp;&nbsp;' . esc_html__( 'You are currently running', 'allcom') . ' Redux Framework ' . esc_html__('version','allcom' ) . ' ' . $redux_ver . '.<br/><br/>' . esc_html__('This field will not render in your option panel, and featuress of this extension will not be available until the latest version of','allcom' ) . ' Redux Framework ' . esc_html__('has been installed.','allcom' );
                    
                    $data = array(
                        'parent'    => $this->parent,
                        'type'      => 'error',
                        'msg'       => $msg,
                        'id'        => $this->ext_name . '_notice_' . self::$version,
                        'dismiss'   => false
                    );
                    
                    if (method_exists('Redux_Admin_Notices', 'set_notice')) {
                        Redux_Admin_Notices::set_notice($data);
                    } else {
                        echo '<div class="error">';
                        echo     '<p>';
                        echo         $msg;
                        echo     '</p>';
                        echo '</div>';
                    }
                    
                    return false;
                }
            }
            
            return true;
        }        
    } // class
} // if
