<?php
 /**
 * Add Button widget.
 */
class Visualmodo_Button extends WP_Widget {

    /**
	* Register widget with WordPress.
	*/
	function __construct() {
		parent::__construct(
			'visualmodo_button', // Base ID
			__( 'Visualmodo - Button', 'allcom' ), // Name
			array( 'description' => __( 'Create an infinite styles buttons.', 'allcom' ), ) // Args
		);
    }
 

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget( $args, $instance ) {
        extract( $args );
        $color = apply_filters( 'widget_color', $instance['color'] );
        $button_title = apply_filters( 'widget_button_title', $instance['button_title'] );
        $shape = apply_filters( 'widget_shape', $instance['shape'] );
        $size = apply_filters( 'widget_size', $instance['size'] );
        $url = apply_filters( 'widget_url', $instance['url'] );
        
        echo $before_widget; ?>

        <!-- front display here -->
        <a href="<?php echo $url; ?>" target="_blank" class="btn visualmodo-widget-button <?php echo $shape.' '.$size.' '.$color; ?>" role="button"><span><?php echo $button_title; ?></span></a>
            
        <?php echo $after_widget;

    }
    

    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form( $instance ) {
        // Color
        if ( isset( $instance[ 'color' ] ) ) {
            $color = $instance[ 'color' ];
        }
        else {
            $color = '';
        }

        // Shape
        if ( isset( $instance[ 'shape' ] ) ) {
            $shape = $instance[ 'shape' ];
        }
        else {
            $shape = '';
        }

        // Size
        if ( isset( $instance[ 'size' ] ) ) {
            $size = $instance[ 'size' ];
        }
        else {
            $size = '';
        }

        // URL
        if ( isset( $instance[ 'url' ] ) ) {
            $url = $instance[ 'url' ];
        }
        else {
            $url = '';
        }

        // Title
        if ( isset( $instance[ 'button_title' ] ) ) {
            $button_title = $instance[ 'button_title' ];
        }
        else {
            $button_title = '';
        }

        ?>

        <p>
			<label for="<?php echo $this->get_field_id('color'); ?>"><?php _e('Color:', 'allcom') ?></label>
			<select id="<?php echo $this->get_field_id('color'); ?>" name="<?php echo $this->get_field_name('color'); ?>" class="widefat">
                <option value='visualmodo-widget-button--primary-color'<?php selected( $color, 'visualmodo-widget-button--primary-color'); ?>><?php _e( 'Primary Color', 'allcom' ); ?></option>
                <option value='visualmodo-widget-button--secondary-color'<?php selected( $color, 'visualmodo-widget-button--secondary-color'); ?>><?php _e( 'Secondary Color', 'allcom' ); ?></option> 
                <option value='visualmodo-widget-button--tertiary-color'<?php selected( $color, 'visualmodo-widget-button--tertiary-color'); ?>><?php _e( 'Tertiary Color', 'allcom' ); ?></option> 
                <option value='visualmodo-widget-button--contrast-color'<?php selected( $color, 'visualmodo-widget-button--contrast-color'); ?>><?php _e( 'Contrast Color', 'allcom' ); ?></option> 
			</select>
        </p>
        <p>
			<label for="<?php echo $this->get_field_id('shape'); ?>"><?php _e('Shape:', 'allcom') ?></label>
			<select id="<?php echo $this->get_field_id('shape'); ?>" name="<?php echo $this->get_field_name('shape'); ?>" class="widefat">
                <option value='visualmodo-widget-button--rounded'<?php selected( $shape, 'visualmodo-widget-button--rounded'); ?>><?php _e( 'Rounded', 'allcom' ); ?></option>
                <option value='visualmodo-widget-button--round'<?php selected( $shape, 'visualmodo-widget-button--round'); ?>><?php _e( 'Round', 'allcom' ); ?></option> 
                <option value='visualmodo-widget-button--square'<?php selected( $shape, 'visualmodo-widget-button--square'); ?>><?php _e( 'Square', 'allcom' ); ?></option> 
                <option value='visualmodo-widget-button--outline-rounded'<?php selected( $shape, 'visualmodo-widget-button--outline-rounded'); ?>><?php _e( 'Outline Rounded', 'allcom' ); ?></option>
                <option value='visualmodo-widget-button--outline-round'<?php selected( $shape, 'visualmodo-widget-button--outline-round'); ?>><?php _e( 'Outline Round', 'allcom' ); ?></option> 
                <option value='visualmodo-widget-button--outline-square'<?php selected( $shape, 'visualmodo-widget-button--outline-square'); ?>><?php _e( 'Outline Square', 'allcom' ); ?></option> 
			</select>
        </p>
        <p>
			<label for="<?php echo $this->get_field_id('size'); ?>"><?php _e('Size:', 'allcom') ?></label>
			<select id="<?php echo $this->get_field_id('size'); ?>" name="<?php echo $this->get_field_name('size'); ?>" class="widefat">
                <option value=''<?php selected( $size, ''); ?>><?php _e( 'Default', 'allcom' ); ?></option>
                <option value='btn-sm'<?php selected( $size, 'btn-sm'); ?>><?php _e( 'Small', 'allcom' ); ?></option> 
                <option value='btn-lg'<?php selected( $size, 'btn-lg'); ?>><?php _e( 'Large', 'allcom' ); ?></option> 
                <option value='btn-block'<?php selected( $size, 'btn-block'); ?>><?php _e( 'Block', 'allcom' ); ?></option> 
			</select>
        </p>
        <p>
            <label for="<?php echo $this->get_field_name( 'button_title' ); ?>"><?php _e( 'Title:', 'allcom' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'button_title' ); ?>" name="<?php echo $this->get_field_name( 'button_title' ); ?>" type="text" value="<?php echo esc_attr( $button_title ); ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_name( 'url' ); ?>"><?php _e( 'URL:', 'allcom' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'url' ); ?>" name="<?php echo $this->get_field_name( 'url' ); ?>" type="text" value="<?php echo esc_attr( $url ); ?>" />
        </p>
    <?php }
    

    /**
     * Sanitize widget form values as they are saved.
     *
     * @see WP_Widget::update()
     *
     * @param array $new_instance Values just sent to be saved.
     * @param array $old_instance Previously saved values from database.
     *
     * @return array Updated safe values to be saved.
     */
    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['color'] = ( !empty( $new_instance['color'] ) ) ? strip_tags( $new_instance['color'] ) : '';
        $instance['button_title'] = ( !empty( $new_instance['button_title'] ) ) ? strip_tags( $new_instance['button_title'] ) : '';
        $instance['shape'] = ( !empty( $new_instance['shape'] ) ) ? strip_tags( $new_instance['shape'] ) : '';
        $instance['size'] = ( !empty( $new_instance['size'] ) ) ? strip_tags( $new_instance['size'] ) : '';
        $instance['url'] = ( !empty( $new_instance['url'] ) ) ? strip_tags( $new_instance['url'] ) : '';
        return $instance;
    }
}

// register Visualmodo_Button widget
add_action( 'widgets_init', 'register_visualmodo_button' );

function register_visualmodo_button() {
    register_widget( 'Visualmodo_Button' );
}