<?php
/**
 * Adds Visualmodo_Spacer widget.
 */
class Visualmodo_Spacer extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'visualmodo_spacer', // Base ID
			__( 'Visualmodo - Spacer', 'allcom' ), // Name
			array( 'description' => __( 'Blank space with custom height.', 'allcom' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		extract( $args );
		$space = apply_filters('widget_space', $instance['space']);
		
		echo $before_widget;
		
		if ( ! empty( $space ) ) { ?>
			
			<div class="visualmodo-widget spacer" style="height:<?php echo $instance['space'] ?>;"></div>

		<?php } ?>
		<?php echo $after_widget;
	}
	
	
        /**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
        public function form( $instance ) {
		//print_r($instance);
        	
        	if ( isset( $instance[ 'space' ] ) ) {
        		$space = $instance[ 'space' ];
        	}
        	else {
        		$space = '';
        	}
        	
        	?>

        	
        	<p>
        		<label for="<?php echo $this->get_field_id( 'space' ); ?>"><?php _e( 'Space - CSS measurement units allowed', 'allcom' ); ?></label> 
        		<input class="widefat" id="<?php echo $this->get_field_id( 'space' ); ?>" name="<?php echo $this->get_field_name( 'space' ); ?>" type="text" value="<?php echo esc_attr( $space ); ?>" />
        	</p>
        	
        <?php }


   /**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
   public function update( $new_instance, $old_instance ) {
   	$instance = array();
   	$instance['space'] = ( !empty( $new_instance['space'] ) ) ? strip_tags( $new_instance['space'] ) : '';
   	
   	return $instance;
   }
   
} // class Visualmodo_Spacer ends



// register Visualmodo_Spacer widget
function register_visualmodo_spacer() {
	register_widget( 'Visualmodo_Spacer' );
}
add_action( 'widgets_init', 'register_visualmodo_spacer' );