<?php

//Variables > Theme Options
$options = get_option('visualmodo');
$header_levels = $options['header_levels'] ?? array('main');
$header_boxed_or_stretched = $options['header_boxed_or_stretched'] ?? 'container';
$body_boxed_or_stretched = $options['body_boxed_or_stretched'] ?? 'container-fluid p-0';
$header_color_theming = $options['header_color_theming'] ?? 'light-theme';
$corners = 'rounded-corners'; // Remove on next Version
// Custom Code
$custom_css_header = $options['custom_css_header'] ?? '';
$custom_js_header = $options['custom_js_header'] ?? '';
$google_analytics = $options['google_analytics'] ?? '';
$google_adsense = $options['google_adsense'] ?? '';
// Component - Buttons
$buttons_color = $options['buttons_color'] ?? 'component-button-primary-color';
$buttons_shape = $options['buttons_shape'] ?? 'component-button-rounded';
// Component - Cards
$cards_shape = $options['cards_shape'] ?? 'component-card-rounded';
// Component - Text Fields
$text_fields_shape = $options['text_fields_shape'] ?? 'component-text-fields-rounded';

$top_header_layout_fit_content = $main_header_layout_fit_content = $bottom_header_layout_fit_content = $mobile_header_layout_fit_content = $level_header_cells_total = '';

foreach ( $header_levels as $level ) {
	${$level.'_header_layout_fit_content'} = $options[$level.'_header_layout_fit_content'] ?? 'top-header-layout-no-fit-content';
	${$level.'_header_layout'} = $options[$level.'_header_layout'] ?? array( "left" => array( "logo" => 'Logo' ), "center" => array( "primary_nav" => 'Primary Nav' ), "right" => array( "search" => 'Search', "toggle" => 'Toggle Navigation' ) );
	${$level.'_header_show'} = $options[$level.'_header_show'] ?? array('2', '3');
	${$level.'_header_left_content_position'} = $options[$level.'_header_left_content_position'] ?? 'justify-start';
	${$level.'_header_center_content_position'} = $options[$level.'_header_center_content_position'] ?? 'justify-center';
	${$level.'_header_right_content_position'} = $options[$level.'_header_right_content_position'] ?? 'justify-end';
}

?>

<!doctype html>
<html <?php language_attributes(); ?>>
<head>

	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<!-- Custom CSS -->
	<?php if(($custom_css_header)) echo '<style type="text/css">'. $custom_css_header .'</style>'; ?> 
	<!-- Custom JS -->
	<?php if(($custom_js_header)) echo '<script type="text/javascript">'. $custom_js_header .'</script>'; ?> 
	<!-- Google Analytics -->
	<?php if(($google_analytics)) echo $google_analytics; ?>
	<!-- Google Ad Sense -->
	<?php if(($google_adsense)) echo $google_adsense; ?>

	<?php wp_head(); ?> 

</head>

<body <?php body_class($top_header_layout_fit_content .' '. $main_header_layout_fit_content .' '. $bottom_header_layout_fit_content .' '. $mobile_header_layout_fit_content .' '. $corners .' '. $buttons_color .' '. $buttons_shape .' '. $cards_shape .' '. $text_fields_shape); ?>>
<?php do_action( 'wp_body_open' ); ?>
<div id="page" class="site <?php echo $body_boxed_or_stretched; ?>">
	<a class="skip-link sr-only sr-only-focusable" href="#content"><?php esc_html_e( 'Skip to content', 'allcom' ); ?></a>

	<header id="masthead" class="<?php echo $header_color_theming; ?>">
		<div class="header__container navbar-light <?php echo $header_boxed_or_stretched; ?>">

			<?php $align_items = array('left', 'center', 'right'); ?>
			<?php foreach ( $header_levels as $level ) {
				set_query_var( 'header_level', $level );
				// Start Show Header Breakpoint 
				$sm = 'd-none d-sm-none';
				$md = 'd-md-none';
				$lg = 'd-lg-none';

				foreach (${$level.'_header_show'} as $key => $value) {
					switch($value) {
						case '1': $sm = 'd-sm-block';
						break;
						case '2': $md = 'd-md-block';
						break;
						case '3': $lg = 'd-lg-block';
						break;
					}
				}

				${$level.'_header_show'} = $sm.' '.$md.' '.$lg;
				// End Show Header Breakpoint

				// Start Header Cells Counter
				foreach ( $align_items as $align_item ) {
					if (count(${$level.'_header_layout'}[$align_item]) >= 1) {
						$level_header_cells_total = $level_header_cells_total.'-'.$align_item;
					}
				}
				// End Header Cells Counter

				?><div class="<?php echo $level.'-header'.' header__container-row'.$level_header_cells_total.' '.${$level.'_header_show'}; ?>"><?php

					foreach ( $align_items as $align_item ) {
					
						if (count(${$level.'_header_layout'}[$align_item]) >= 1) {

							?><div class="<?php echo $level; ?>-header-layout-fit-content-<?php echo $align_item; ?> <?php echo ${$level.'_header_'.$align_item.'_content_position'}; ?>"><?php
								
								foreach (${$level.'_header_layout'}[$align_item] as $key=>$value) {

									set_query_var( 'header_layout_item_position', 'header-item-'.$align_item );
							
									switch($key) {

										// Brand
										case 'logo': get_template_part('views/partials/header/branding');
										break;

										// Cart
										case 'cart': get_template_part('views/partials/header/cart');
										break;

										// Primary Navigation
										case 'primary_nav': get_template_part('views/partials/header/primary_navigation');
										break;

										// Secondary Navigation
										case 'secondary_nav': get_template_part('views/partials/header/secondary_navigation');
										break;

										// Tertiary Navigation
										case 'tertiary_nav': get_template_part('views/partials/header/tertiary_navigation');
										break;

										// Logo And Single Navigation
										case 'logo_nav': 
											get_template_part('views/partials/header/single_navigation');
										break;

										// Logo And Split Navigation
										case 'logo_split_nav': 
											get_template_part('views/partials/header/split_navigation');
										break;

										// Toogle Navigation
										case 'toggle': get_template_part('views/partials/header/toggle');
										break;

										// Search
										case 'search': get_template_part('views/partials/header/search');
										break;

										// First Widget
										case 'first_widget': 
											if ( is_active_sidebar( 'first-header' ) ) {
												dynamic_sidebar('first-header');
											}
										break;

										// Second Widget
										case 'second_widget': 
											if ( is_active_sidebar( 'second-header' ) ) {
												dynamic_sidebar('second-header');
											}
										break;

										// Third Widget
										case 'third_widget': 
											if ( is_active_sidebar( 'third-header' ) ) {
												dynamic_sidebar('third-header');
											}
										break;

										// Fourth Widget
										case 'fourth_widget': 
											if ( is_active_sidebar( 'fourth-header' ) ) {
												dynamic_sidebar('fourth-header');
											}
										break;

										// Fifth Widget
										case 'fifth_widget': 
											if ( is_active_sidebar( 'fifth-header' ) ) {
												dynamic_sidebar('fifth-header');
											}
										break;

										// Sixth Widget
										case 'sixth_widget': 
											if ( is_active_sidebar( 'sixth-header' ) ) {
												dynamic_sidebar('sixth-header');
											}
										break;
								
									}
							
								}

							?></div><?php

						}
					
					}

				?></div><?php
				$level_header_cells_total = '';
			}?>	

			<?php get_template_part('views/partials/header/mobile_navigation'); ?>

		</div>
	</header><!-- #masthead -->
	
	<?php get_template_part('views/partials/header/hero'); ?>